package telegram

import (
	"encoding/json"
	"io/ioutil"
	"log"
	"net/http"
	"net/url"
	"strconv"
	"strings"
)

const badChars = "_*[]()~`>#+-=|{}.!"

type Client struct {
	Key    string
	Offset int64
}

func (c *Client) GetUpdates() (Response, error) {
	var res Response

	resp, err := http.Get("https://api.telegram.org/" + c.Key + "/getUpdates?offset=" + strconv.FormatInt(c.Offset, 10))
	if err != nil {
		return res, err
	}

	body, err := ioutil.ReadAll(resp.Body)
	if err != nil {
		return res, err
	}

	err = json.Unmarshal(body, &res)

	if len(res.Result) > 0 {
		log.Println("Last update: ", res.Result[len(res.Result)-1].UpdateID)
		c.Offset = res.Result[len(res.Result)-1].UpdateID + 1
	}

	return res, err
}

func EscapeMarkdown(msg string) string {
	for _, char := range badChars {
		ch := string(char)
		msg = strings.Replace(msg, ch, "\\"+ch, -1)
	}
	return msg
}

func (c *Client) SendMarkdownMessage(chatId, body string) (*SendMessageResponse, error) {
	return c.SendMessage(chatId, body, url.Values{"parse_mode": {"MarkdownV2"}})
}

func (c *Client) SendMessage(chatId, body string, options ...url.Values) (ret *SendMessageResponse, err error) {
	values := url.Values{
		"chat_id": {chatId},
		"text":    {body},
	}
	for _, vals := range options {
		for key, val := range vals {
			values[key] = val
		}
	}

	response, err := http.PostForm("https://api.telegram.org/"+c.Key+"/sendMessage", values)
	if err != nil {
		return nil, err
	}

	defer func() {
		err = response.Body.Close()
	}()

	resbody, err := ioutil.ReadAll(response.Body)
	if err != nil {
		return nil, err
	}

	var res SendMessageResponse
	err = json.Unmarshal(resbody, &res)
	return &res, err
}
